# Some ideas for this spec file taken from a prior attempt by Richard
# W. M. Jones

#  General Information
# This program has its own version of cil, there is an ocaml-cil upon which this
# based, however the version contained in this package has custom mods that
# are not availible with the ocaml-cil because the upstream has
# forked their own version of cil.

%global debug_package %{nil}
%global __strip /usr/bin/true
%global opt %(test -x %{_bindir}/ocamlopt && echo 1 || echo 0)
%if %opt
%global ocamlbest opt
%else
%global ocamlbest byte
%endif

%global pkgversion Fluorine-20130601

Name:           frama-c
Version:        1.9
Release:        %mkrel -c 20130601Fluorine 2
Summary:        Framework for source code analysis of C software

Group:          Sciences/Computer science
# Licensing breakdown in source file frama-c-1.6-licensing
License:        LGPLv2 and GPLv2 and GPLv2+ and BSD and (QPL with exceptions)
URL:            http://frama-c.com/
Source0:        http://frama-c.com/download/%{name}-%{pkgversion}.tar.gz
Source1:        frama-c-1.6.licensing
Source2:        %{name}-gui.desktop
Source3:        acsl.el
# Post-release fixes from upstream
Patch0:         %{name}-fixes.patch
Patch1:         frama-c-Fluorine-20130601-mageia-fix-make-detection.patch
Patch2:         frama-c-Fluorine-20130601-upstream-4.01-compat.patch

BuildRequires:  alt-ergo
BuildRequires:  coq
BuildRequires:  desktop-file-utils
BuildRequires:  emacs-nox
BuildRequires:  gmp-devel
BuildRequires:  graphviz
BuildRequires:  gtksourceview2-devel
BuildRequires:  pkgconfig(libgnomecanvas-2.0)
BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  ltl2ba
BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-findlib-devel
BuildRequires:  ocaml-lablgtk2-devel
BuildRequires:  ocaml-ocamlgraph-devel
BuildRequires:  ocaml-zarith-devel

Requires:       gcc-cpp
Requires:       graphviz
Requires:       ltl2ba

# This can be removed once F-19 goes EOL
Obsoletes:      %{name}-devel < 1.9-1
Provides:       %{name}-devel = %{version}-%{release}

%description
Frama-C is a suite of tools dedicated to the analysis of the source
code of software written in C.

Frama-C gathers several static analysis techniques in a single
collaborative framework. The collaborative approach of Frama-C allows
static analyzers to build upon the results already computed by other
analyzers in the framework. Thanks to this approach, Frama-C provides
sophisticated tools, such as a slicer and dependency analysis.

%package doc
Summary:        Large documentation files for %{name}
Group:          Documentation 
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description doc
Large documentation files for %{name}.

%package emacs
Summary:        Emacs support file for ACSL markup
Group:          Editors
License:        LGPLv2
Requires:       %{name} = %{version}-%{release}
Requires:       emacs
BuildArch:      noarch

%description emacs
This package contains an Emacs support file for working with C source
files marked up with ACSL.

%prep
%setup -q -n %{name}-%pkgversion
%patch0
%patch1 -p1
%patch2 -p1

# Fix encodings
iconv -f iso-8859-1 -t utf8 man/frama-c.1 > man/frama-c.1.conv
touch -r man/frama-c.1 man/frama-c.1.conv
mv -f man/frama-c.1.conv man/frama-c.1

%build
# This option prints the actual make commands so we can see what's
# happening (eg: for debugging the spec file)
%global framac_make_options VERBOSEMAKE=yes OCAMLBEST=%{ocamlbest}

# Fake the existence of why so the plugin is built
touch why why-dp
chmod a+x why why-dp
PATH=${PATH}:${PWD}

autoconf
%configure
# Harden the build due to network use
make %{framac_make_options} \
OLINKFLAGS="-I +zarith -I +ocamlgraph -I +lablgtk2 -ccopt -Wl,-z,relro,-z,now"

%install
make install DESTDIR=%{buildroot} %{framac_make_options}

%if %opt
strip %{buildroot}%{_bindir}/frama-c
strip %{buildroot}%{_bindir}/frama-c-gui
strip %{buildroot}%{_libdir}/frama-c/plugins/*.cmxs
strip %{buildroot}%{_libdir}/frama-c/plugins/gui/*.cmxs
%else
mv -f %{buildroot}%{_bindir}/frama-c.byte %{buildroot}%{_bindir}/frama-c
mv -f %{buildroot}%{_bindir}/frama-c-gui.byte %{buildroot}%{_bindir}/frama-c-gui
%endif
desktop-file-install                                    \
--dir=${RPM_BUILD_ROOT}%{_datadir}/applications/         \
%{SOURCE2}

# Install and bytecompile the Emacs file
mkdir -p %{buildroot}%{_datadir}/emacs/site-lisp/
mv %{buildroot}%{_datadir}/frama-c/acsl.el %{buildroot}%{_datadir}/emacs/site-lisp/
chmod a-x %{buildroot}%{_datadir}/emacs/site-lisp/acsl.el
cd %{buildroot}%{_datadir}/emacs/site-lisp/
emacs -batch  -f batch-byte-compile acsl.el
mkdir -p %{buildroot}%{_sysconfdir}/emacs/site-start.d/
cp -p %{SOURCE3} %{buildroot}%{_sysconfdir}/emacs/site-start.d/

# The install step adds lots of spurious executable bits
find %{buildroot}%{_datadir}/frama-c -type f -perm /0111 | \
xargs chmod a-x %{buildroot}%{_libdir}/frama-c/*.cmx \
                %{buildroot}%{_mandir}/man1/*

%files
%doc licenses/* doc/manuals/user-manual.pdf VERSION
%{_bindir}/*
%if %opt
%exclude %{_bindir}/frama-c.byte
%exclude %{_bindir}/frama-c-gui.byte
%exclude %{_bindir}/ptests.byte
%endif
%exclude %{_libdir}/frama-c/*.cmo
%exclude %{_libdir}/frama-c/*.cmx
%exclude %{_libdir}/frama-c/*.o
%{_libdir}/frama-c/
%{_datadir}/frama-c/
%{_datadir}/applications/*.desktop
%{_mandir}/man1/*

%files doc
%doc doc/code/*.txt
%doc doc/manuals/acsl*
%doc doc/manuals/aorai-manual.pdf
%doc doc/manuals/metrics-manual.pdf
%doc doc/manuals/plugin-development-guide.pdf
%doc doc/manuals/rte-manual.pdf
%doc doc/manuals/value-analysis.pdf
%doc doc/manuals/wp-manual.pdf

%files emacs
%{_datadir}/emacs/site-lisp/acsl.elc
%{_sysconfdir}/emacs/site-start.d/acsl.el
%{_datadir}/emacs/site-lisp/acsl.el


%changelog
* Tue Nov 19 2013 malo <malo> 1.9-0.20130601Fluorine.2.mga4
+ Revision: 551930
- fix requires

* Tue Nov 19 2013 malo <malo> 1.9-0.20130601Fluorine.1.mga4
+ Revision: 551925
- fix emacs mode packaging
- add BR ncurses
- spec clean-up after import from Fedora
- add patch from upstream for ocaml-4.01 compatibility
- add patch for new version of make
- imported package frama-c

